==> bitcream-smartsignage-custom-v0.6-16ba45.zip: common/models/Preset.php <==
<?php

namespace bitcream\smartsignage\custom\common\models;

use Yii;
use bitcream\smartsignage\custom\common\behaviors\StatusBehaviors;
use bitcream\smartsignage\custom\common\behaviors\CreateUpdateBehaviors;
use yii2tech\ar\softdelete\SoftDeleteBehavior;

/**
 * This is the model class for table "{{%preset}}".
 *
 */
class Preset extends base\Preset
{
    public function behaviors()
    {
        return array_merge(parent::behaviors(), [
            'status' => [
                'class' => StatusBehaviors::className(),
            ],
            'create-update' => [
                'class' => CreateUpdateBehaviors::className(),
            ],
            'softDeleteBehavior' => [
                'class' => SoftDeleteBehavior::className(),
                'softDeleteAttributeValues' => [
                    'status' => 0
                ],
                'replaceRegularDelete' => true // mutate native `delete()` method
            ],
       ]);
    }


    public function getClasses()
    {
        return [
            \bitcream\smartsignage\custom\common\models\Image::className() => \bitcream\smartsignage\custom\common\models\Image::getContentType(),
            \bitcream\smartsignage\custom\common\models\Audio::className() => \bitcream\smartsignage\custom\common\models\Audio::getContentType(),
            \bitcream\smartsignage\custom\common\models\Video::className() => \bitcream\smartsignage\custom\common\models\Video::getContentType(),
            \bitcream\smartsignage\custom\common\models\Text::className() => \bitcream\smartsignage\custom\common\models\Text::getContentType(),
            \bitcream\smartsignage\custom\common\models\Iframe::className() => \bitcream\smartsignage\custom\common\models\Iframe::getContentType(),
        ];
    }

}

==> bitcream-smartsignage-custom-v0.7.1-31692a.zip: common/models/Preset.php <==
<?php

namespace bitcream\smartsignage\custom\common\models;

use Yii;
use bitcream\smartsignage\custom\common\behaviors\StatusBehaviors;
use bitcream\smartsignage\custom\common\behaviors\CreateUpdateBehaviors;
use yii2tech\ar\softdelete\SoftDeleteBehavior;

/**
 * This is the model class for table "{{%preset}}".
 *
 */
class Preset extends base\Preset
{
    public function behaviors()
    {
        return array_merge(parent::behaviors(), [
            'status' => [
                'class' => StatusBehaviors::className(),
            ],
            'create-update' => [
                'class' => CreateUpdateBehaviors::className(),
            ],
            'softDeleteBehavior' => [
                'class' => SoftDeleteBehavior::className(),
                'softDeleteAttributeValues' => [
                    'status' => 0
                ],
                'replaceRegularDelete' => true // mutate native `delete()` method
            ],
       ]);
    }


    public function getClasses()
    {
        return [
            \bitcream\smartsignage\custom\common\models\Image::className() => \bitcream\smartsignage\custom\common\models\Image::getContentType(),
            // \bitcream\smartsignage\custom\common\models\Audio::className() => \bitcream\smartsignage\custom\common\models\Audio::getContentType(),
            \bitcream\smartsignage\custom\common\models\Video::className() => \bitcream\smartsignage\custom\common\models\Video::getContentType(),
            \bitcream\smartsignage\custom\common\models\Text::className() => \bitcream\smartsignage\custom\common\models\Text::getContentType(),
            \bitcream\smartsignage\custom\common\models\Iframe::className() => \bitcream\smartsignage\custom\common\models\Iframe::getContentType(),
            \bitcream\smartsignage\custom\common\models\Slider::className() => \bitcream\smartsignage\custom\common\models\Slider::getContentType(),

        ];
    }

}
